@@ -31,7 +31,6 @@ FEEDBACK_HREF_PATTERN = u'{}/v3/wml_instances/{}/published_models/{}/feedback'
 
 DEPLOYMENTS_HREF_PATTERN = u'{}/v3/wml_instances/{}/deployments'
 DEPLOYMENT_HREF_PATTERN = u'{}/v3/wml_instances/{}/deployments/{}'
-PAYLOAD_LOGGING_HREF_PATTERN = u'{}/v3/wml_instances/{}/deployments/{}/payload_logging_configuration'
 MODEL_LAST_VERSION_HREF_PATTERN = u'{}/v3/ml_assets/models/{}'
 DEFINITION_HREF_PATTERN = u'{}/v3/ml_assets/training_definitions/{}'
 DEFINITIONS_HREF_PATTERN = u'{}/v3/ml_assets/training_definitions'
@@ -45,6 +44,10 @@ RUNTIMES_HREF_PATTERN = u'{}/v4/runtimes'
 CUSTOM_LIB_HREF_PATTERN = u'{}/v4/libraries/{}'
 CUSTOM_LIBS_HREF_PATTERN = u'{}/v4/libraries'
 
+IAM_TOKEN_API = u'{}&grant_type=urn%3Aibm%3Aparams%3Aoauth%3Agrant-type%3Aapikey'
+IAM_TOKEN_URL = u'{}/oidc/token'
+PROD_URL = ['https://us-south.ml.cloud.ibm.com','https://eu-gb.ml.cloud.ibm.com','https://eu-de.ml.cloud.ibm.com','https://jp-tok.ml.cloud.ibm.com','https://ibm-watson-ml.mybluemix.net','https://ibm-watson-ml.eu-gb.bluemix.net',
+            'https://private.us-south.ml.cloud.ibm.com','https://private.eu-gb.ml.cloud.ibm.com','https://private.eu-de.ml.cloud.ibm.com','https://private.jp-tok.ml.cloud.ibm.com']
 
 def is_url(s):
     res = re.match('https?:\/\/.+', s)
@@ -120,9 +123,6 @@ class HrefDefinitions:
     def get_deployment_href(self, deployment_uid):
         return DEPLOYMENT_HREF_PATTERN.format(self._wml_credentials['url'], self._wml_credentials['instance_id'], deployment_uid)
 
-    def get_payload_logging_href(self, deployment_uid):
-        return PAYLOAD_LOGGING_HREF_PATTERN.format(self._wml_credentials['url'], self._wml_credentials['instance_id'], deployment_uid)
-
     def get_definition_href(self, definition_uid):
         return DEFINITION_HREF_PATTERN.format(self._wml_credentials['url'], definition_uid)
 
@@ -148,4 +148,13 @@ class HrefDefinitions:
         return CUSTOM_LIB_HREF_PATTERN.format(self._wml_credentials['url'], library_uid)
 
     def get_custom_libraries_href(self):
-        return CUSTOM_LIBS_HREF_PATTERN.format(self._wml_credentials['url'])
\ No newline at end of file
+        return CUSTOM_LIBS_HREF_PATTERN.format(self._wml_credentials['url'])
+
+    def get_iam_token_api(self):
+        return IAM_TOKEN_API.format(self._wml_credentials['apikey'])
+
+    def get_iam_token_url(self):
+        if(self._wml_credentials['url'] in PROD_URL):
+            return IAM_TOKEN_URL.format('https://iam.cloud.ibm.com')
+        else:
+            return IAM_TOKEN_URL.format('https://iam.test.cloud.ibm.com')
