@@ -27,6 +27,7 @@ class LearningSystem(WMLResource):
         WMLResource.__init__(self, __name__, client)
         self.ConfigurationMetaNames = LearningSystemMetaNames()
         self._run_uid_to_model_uid_mapping = {}
+        self._ICP = client.ICP
 
     def _get_model_uid_by_run_uid(self, run_uid):
 
@@ -39,8 +40,9 @@ class LearningSystem(WMLResource):
                 return self._href_definitions.get_learning_iterations_href(model_uid)
 
             headers = self._client._get_headers()
+            isIcp = self._ICP
 
-            tasks = [pool.apply_async(get_url, (url(resource[u'metadata'][u'guid']), headers)) for resource in models[u'resources']]
+            tasks = [pool.apply_async(get_url, (url(resource[u'metadata'][u'guid']), headers, None, isIcp)) for resource in models[u'resources']]
 
             for task in tasks:
                 response = task.get()
@@ -66,7 +68,7 @@ class LearningSystem(WMLResource):
             :return: learning system configuration details
             :rtype: dict
 
-            A way you might use me is
+            **Example**:
 
             >>> learning_system = client.learning_system.create(model_uid, meta_props=configuration)
         """
@@ -81,29 +83,39 @@ class LearningSystem(WMLResource):
             headers=self._client._get_headers()
         )
 
-        model_details = self._handle_response(200, u'creating new model', model_details_response)
-        training_data_reference = model_details['entity']['training_data_reference']
-        training_result_reference = model_details['entity']['model_version']['content_location']
-        execution = {}
+        self._handle_response(200, u'creating new model', model_details_response)
+        headers = self._client._get_headers()
+        if self.ConfigurationMetaNames.SPARK_REFERENCE in meta_props.keys():
+            spark_instance = {
+                u'credentials': meta_props[self.ConfigurationMetaNames.SPARK_REFERENCE],
+                u'version': u'2.1'
+            }
 
-        print("Model details: {}\n".format(model_details))
-        spark_instance = {
-            u'credentials': meta_props[self.ConfigurationMetaNames.SPARK_REFERENCE],
-            u'version': u'2.1'
-        }
+            headers.update({
+                u'X-Spark-Service-Instance': base64.b64encode(json.dumps(spark_instance).encode('utf-8'))
+            })
 
-        headers = {
-            u'Content-Type': u'application/json',
-            u'Authorization': u'Bearer ' + self._client.service_instance._get_token(),
-            u'X-Spark-Service-Instance': base64.b64encode(json.dumps(spark_instance).encode('utf-8'))
-        }
+            payload = {
+                u'feedback_data_reference': meta_props[self.ConfigurationMetaNames.FEEDBACK_DATA_REFERENCE],
+                u'min_feedback_data_size': meta_props[self.ConfigurationMetaNames.MIN_FEEDBACK_DATA_SIZE],
+                u'auto_retrain': meta_props[self.ConfigurationMetaNames.AUTO_RETRAIN],
+                u'auto_redeploy': meta_props[self.ConfigurationMetaNames.AUTO_REDEPLOY]
+            }
+        elif self.ConfigurationMetaNames.TRAINING_RESULTS_REFERENCE in meta_props.keys():
+            # headers = {
+            #     u'Content-Type': u'application/json',
+            #     u'Authorization': u'Bearer ' + self._client.service_instance._get_token(),
+            # }
 
-        payload = {
-            u'feedback_data_reference': meta_props[self.ConfigurationMetaNames.FEEDBACK_DATA_REFERENCE],
-            u'min_feedback_data_size': meta_props[self.ConfigurationMetaNames.MIN_FEEDBACK_DATA_SIZE],
-            u'auto_retrain': meta_props[self.ConfigurationMetaNames.AUTO_RETRAIN],
-            u'auto_redeploy': meta_props[self.ConfigurationMetaNames.AUTO_REDEPLOY]
-        }
+            payload = {
+                u'training_results_reference': meta_props[self.ConfigurationMetaNames.TRAINING_RESULTS_REFERENCE],
+                u'min_feedback_data_size': meta_props[self.ConfigurationMetaNames.MIN_FEEDBACK_DATA_SIZE],
+                u'auto_retrain': meta_props[self.ConfigurationMetaNames.AUTO_RETRAIN],
+                u'auto_redeploy': meta_props[self.ConfigurationMetaNames.AUTO_REDEPLOY],
+                u'execution': {
+                    u'compute_configuration': meta_props[self.ConfigurationMetaNames.COMPUTE_CONFIGURATION]
+                }
+            }
 
         response = requests.put(
             self._href_definitions.get_learning_configuration_href(model_uid),
@@ -125,6 +137,13 @@ class LearningSystem(WMLResource):
 
         :return: metadata of updated learning system
         :rtype: dict
+
+        **Example**
+         >>> metadata = {
+         >>> client.learning_system.ConfigurationMetaNames.NAME:"updated_function"
+         >>> }
+         >>> learning_system_details = client.learning_system.update(model_uid, changes=metadata)
+
         """
         model_uid = str_type_conv(model_uid)
         self._validate_type(model_uid, u'model_uid', STR_TYPE, True)
@@ -149,7 +168,10 @@ class LearningSystem(WMLResource):
             :param model_uid: ID of model for this learning system
             :type model_uid: str
 
-            A way you might use me is
+            :returns: learning system details
+            :rtype: dict
+
+            **Example**:
 
             >>> learning_system_details = client.learning_system.get_details(model_uid)
         """
@@ -169,7 +191,13 @@ class LearningSystem(WMLResource):
         """
             List existing learning systems.
 
-            A way you might use me is
+           :returns: None
+           :rtype: None
+
+           .. note::
+               This function only prints the list of existing learning_systems
+
+            **Example**:
 
             >>> client.learning_system.list()
         """
@@ -192,7 +220,9 @@ class LearningSystem(WMLResource):
             :param asynchronous: if the run should be asynchronous (optional)
             :type asynchronous: bool
 
-            A way you might use me is
+            :rtype: dict
+
+            **Example**:
 
             >>> client.learning_system.run(model_uid)
             >>> client.learning_system.run(model_uid, asynchronous=False)
@@ -267,7 +297,7 @@ class LearningSystem(WMLResource):
             :return: run uid
             :rtype: str
 
-            A way you might use me is
+            **Example**:
 
             >>> run_uid = client.learning_system.get_run_uid(run_details)
         """
@@ -293,7 +323,7 @@ class LearningSystem(WMLResource):
             :return: run href
             :rtype: str
 
-            A way you might use me is
+            **Example**:
 
             >>> run_uid = client.learning_system.get_run_href(run_details)
         """
@@ -316,7 +346,10 @@ class LearningSystem(WMLResource):
             :param model_uid: ID of stored model
             :type model_uid: str
 
-            A way you might use me is
+            :return: Learning Iterations
+            :rtype: dict
+
+            **Example**:
 
             >>> runs_details = client.learning_system.get_runs(model_uid)
         """
@@ -342,7 +375,7 @@ class LearningSystem(WMLResource):
             :param model_uid: ID of stored model
             :type model_uid: str
 
-            A way you might use me is
+            **Example**:
 
             >>> runs_details = client.learning_system.get_metrics(model_uid)
         """
@@ -363,7 +396,13 @@ class LearningSystem(WMLResource):
             :param model_uid: ID of stored model
             :type model_uid: str
 
-            A way you might use me is
+           :returns: None
+           :rtype: None
+
+           .. note::
+               This function only prints the evaluation metrics
+
+            **Example**:
 
             >>> runs_details = client.learning_system.get_metrics(model_uid)
         """
@@ -394,7 +433,13 @@ class LearningSystem(WMLResource):
            :param model_uid: ID of stored model (optional)
            :type model_uid: str
 
-           A way you might use me is
+           :returns: None
+           :rtype: None
+
+           .. note::
+               This function only prints the list of learning iterations
+
+           **Example**:
 
            >>> client.learning_system.list_runs()
         """
@@ -411,8 +456,9 @@ class LearningSystem(WMLResource):
             def url(model_uid):
                 return self._href_definitions.get_learning_iterations_href(model_uid)
             headers = self._client._get_headers()
+            isIcp = self._ICP
 
-            models_runs = [pool.apply_async(get_url, (url(resource[u'metadata'][u'guid']), headers)) for resource in
+            models_runs = [pool.apply_async(get_url, (url(resource[u'metadata'][u'guid']), headers, None, isIcp)) for resource in
                             model_resources]
 
             result = []
@@ -451,7 +497,7 @@ class LearningSystem(WMLResource):
             :param run_uid: ID of learning iteration run
             :type run_uid: str
 
-            A way you might use me is
+            **Example**:
 
             >>> run_details = client.learning_system.get_run_details(run_uid)
         """
@@ -478,7 +524,7 @@ class LearningSystem(WMLResource):
             :param fields: list of fields (optional)
             :type fields: list of strings
 
-            A way you might use me is
+            **Example**:
 
             >>> client.learning_system.send_feedback(model_uid, [["a1", 1, 1.0], ["a2", 2, 3.4]])
             >>> client.learning_system.send_feedback(model_uid, [["a1", 1.0], ["a2", 3.4]], fields=["id", "value"])
